==> igniteui-react-16.16.2.tgz: package/esm5/lib/Avatar.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { AvatarShape_$type } from "./AvatarShape";
import { SizableComponentSize_$type } from "./SizableComponentSize";
/**
 * @hidden
 */
var Avatar = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Avatar, _super);
    function Avatar() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.c = new WCNativeHelper();
        _this.e = null;
        return _this;
    }
    Object.defineProperty(Avatar.prototype, "d", {
        get: function () {
            return this.c;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Avatar.prototype, "nativeElement", {
        get: function () {
            return this.e;
        },
        set: function (a) {
            this.e = a;
            this.c.d = this.e;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Avatar.prototype, "i", {
        get: function () {
            var ret_ = this.d.c("src");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.i("src", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Avatar.prototype, "g", {
        get: function () {
            var ret_ = this.d.c("alt");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.i("alt", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Avatar.prototype, "h", {
        get: function () {
            var ret_ = this.d.c("initials");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.i("initials", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Avatar.prototype, "a", {
        get: function () {
            var ret_ = this.d.c("shape");
            ret_ = enumGetBox(AvatarShape_$type, EnumUtil.getEnumValue(AvatarShape_$type, EnumUtil.parse(AvatarShape_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(AvatarShape_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(AvatarShape_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.d.i("shape", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Avatar.prototype, "b", {
        get: function () {
            var ret_ = this.d.c("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, EnumUtil.parse(SizableComponentSize_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.d.i("size", value_);
        },
        enumerable: false,
        configurable: true
    });
    Avatar.$t = markType(Avatar, 'Avatar', BaseElement.$);
    return Avatar;
}(BaseElement));
export { Avatar };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/Avatar.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { AvatarShape_$type } from "./AvatarShape";
import { SizableComponentSize_$type } from "./SizableComponentSize";
/**
 * @hidden
 */
var Avatar = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Avatar, _super);
    function Avatar() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.c = new WCNativeHelper();
        _this.e = null;
        return _this;
    }
    Object.defineProperty(Avatar.prototype, "d", {
        get: function () {
            return this.c;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Avatar.prototype, "nativeElement", {
        get: function () {
            return this.e;
        },
        set: function (a) {
            this.e = a;
            this.c.o = this.e;
        },
        enumerable: false,
        configurable: true
    });
    Avatar.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(Avatar.prototype, "i", {
        get: function () {
            var ret_ = this.d.n("src");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.v("src", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Avatar.prototype, "g", {
        get: function () {
            var ret_ = this.d.n("alt");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.v("alt", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Avatar.prototype, "h", {
        get: function () {
            var ret_ = this.d.n("initials");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.v("initials", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Avatar.prototype, "a", {
        get: function () {
            var ret_ = this.d.n("shape");
            ret_ = enumGetBox(AvatarShape_$type, EnumUtil.getEnumValue(AvatarShape_$type, this.d.f(AvatarShape_$type, ret_)));
            return EnumUtil.getEnumValue(AvatarShape_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(AvatarShape_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.d.v("shape", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Avatar.prototype, "b", {
        get: function () {
            var ret_ = this.d.n("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.d.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.d.v("size", value_);
        },
        enumerable: false,
        configurable: true
    });
    Avatar.$t = markType(Avatar, 'Avatar', BaseElement.$);
    return Avatar;
}(BaseElement));
export { Avatar };
